@@ -185,7 +185,7 @@ $translations = array(
 	'Save and continue edit' => 'Desa i segueix editant',
 	'original' => 'original',
 	'%d item(s) have been affected.' => array('S\'ha modificat %d element.', 'S\'han modificat %d elements.'),
-	'whole result' => 'tots els resultats',
+	'Whole result' => 'Tots els resultats',
 	'Tables have been dropped.' => 'S\'han suprimit les taules.',
 	'Clone' => 'Clona',
 	'Partition by' => 'Fes particions segons',
